# Server Toolkit for Jutge.org

![Logo](documentation/jutge-toolkit.png)

This package is intended for the server side of the Jutge.org platform. It is not mean for the general public, but for the Jutge.org team.

## Credits

- [Jordi Petit](https://github.com/jordi-petit)
- [Cristina Raluca](https://github.com/ralucado)
- [Jordi Reig](https://github.com/jordireig)

## License

Apache License 2.0
